@@ -25,7 +25,12 @@
 #include "env.h"
 #include "glpios.h"
 #include "glpnpp.h"
+#if 0 /* 07/XI-2015 */
 #include "glpspx.h"
+#else
+#include "simplex.h"
+#define spx_dual spy_dual
+#endif
 
 /***********************************************************************
 *  NAME
@@ -481,7 +486,11 @@ void glp_init_smcp(glp_smcp *parm)
       parm->r_test = GLP_RT_HAR;
       parm->tol_bnd = 1e-7;
       parm->tol_dj = 1e-7;
+#if 0 /* 07/XI-2015 */
       parm->tol_piv = 1e-10;
+#else
+      parm->tol_piv = 1e-9;
+#endif
       parm->obj_ll = -DBL_MAX;
       parm->obj_ul = +DBL_MAX;
       parm->it_lim = INT_MAX;
@@ -812,7 +821,7 @@ int glp_get_it_cnt(glp_prob *P)
 #endif
 
 #if 1 /* 08/VIII-2013 */
-int glp_set_it_cnt(glp_prob *P, int it_cnt)
+void glp_set_it_cnt(glp_prob *P, int it_cnt)
 {     /* set simplex solver iteration count */
       P->it_cnt = it_cnt;
       return;
