@@ -22,8 +22,9 @@
 *  along with GLPK. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
-#include "glpapi.h"
-#include "glpnet.h"
+#include "env.h"
+#include "mc13d.h"
+#include "prob.h"
 
 /***********************************************************************
 *  NAME
