@@ -22,7 +22,8 @@
 *  along with GLPK. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
-#include "glpapi.h"
+#include "env.h"
+#include "prob.h"
 #include "wclique.h"
 
 static void set_edge(int nv, unsigned char a[], int i, int j)
