@@ -375,10 +375,8 @@ static void print_version(int briefly)
       xprintf("GLPSOL: GLPK LP/MIP Solver, v%s\n", glp_version());
       if (briefly) goto done;
       xprintf("\n");
-      xprintf("Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, "
-         "2007, 2008,\n");
-      xprintf("2009, 2010, 2011, 2013, 2014 Andrew Makhorin, Department"
-         " for Applied\n");
+      xprintf("Copyright (C) 2000-2015 Andrew Makhorin, Department for "
+         "Applied\n");
       xprintf("Informatics, Moscow Aviation Institute, Moscow, Russia. "
          "All rights\n");
       xprintf("reserved. E-mail: <mao@gnu.org>.\n");
@@ -687,15 +685,15 @@ static int parse_cmdline(struct csa *csa, int argc, const char *argv[])
             csa->bfcp.type |= GLP_BF_BTF;
          }
          else if (p("--ft"))
-         {  csa->bfcp.type &= 0x0F;
+         {  csa->bfcp.type &= 0xF0;
             csa->bfcp.type |= GLP_BF_FT;
          }
          else if (p("--cbg"))
-         {  csa->bfcp.type &= 0x0F;
+         {  csa->bfcp.type &= 0xF0;
             csa->bfcp.type |= GLP_BF_BG;
          }
          else if (p("--cgr"))
-         {  csa->bfcp.type &= 0x0F;
+         {  csa->bfcp.type &= 0xF0;
             csa->bfcp.type |= GLP_BF_GR;
          }
 #endif
