@@ -23,7 +23,8 @@
 *  along with GLPK. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
-#include "glpapi.h"
+#include "env.h"
+#include "glpk.h"
 
 /***********************************************************************
 *  NAME
@@ -738,6 +739,249 @@ static int iran(struct csa *csa, int ilow, int ihigh)
          return ihigh;
 }
 
+/***********************************************************************
+*  NAME
+*
+*  glp_netgen_prob - Klingman's standard network problem instance
+*
+*  SYNOPSIS
+*
+*  void glp_netgen_prob(int nprob, int parm[1+15]);
+*
+*  DESCRIPTION
+*
+*  The routine glp_netgen_prob provides the set of parameters for
+*  Klingman's network problem generator (see the routine glp_netgen),
+*  which describe a standard network problem instance.
+*
+*  The parameter nprob (101 <= nprob <= 150) specifies the problem
+*  instance number.
+*
+*  The array parm contains description of the network, provided by the
+*  routine. (For detailed description of these parameters see comments
+*  to the routine glp_netgen.)
+*
+*  PROBLEM CHARACTERISTICS
+*
+*  The table below shows characteristics of Klingman's standard network
+*  problem instances.
+*
+*  Problem   Nodes    Arcs      Optimum
+*  -------   -----   -----   ----------
+*    101      5000   25336      6191726
+*    102      5000   25387     72337144
+*    103      5000   25355    218947553
+*    104      5000   25344    -19100371
+*    105      5000   25332     31192578
+*    106      5000   12870      4314276
+*    107      5000   37832      7393769
+*    108      5000   50309      8405738
+*    109      5000   75299      9190300
+*    110      5000   12825      8975048
+*    111      5000   37828      4747532
+*    112      5000   50325      4012671
+*    113      5000   75318      2979725
+*    114      5000   26514      5821181
+*    115      5000   25962      6353310
+*    116      5000   25304      5915426
+*    117      5000   12816      4420560
+*    118      5000   37797      7045842
+*    119      5000   50301      7724179
+*    120      5000   75330      8455200
+*    121      5000   25000     66366360
+*    122      5000   25000     30997529
+*    123      5000   25000     23388777
+*    124      5000   25000     17803443
+*    125      5000   25000     14119622
+*    126      5000   12500     18802218
+*    127      5000   37500     27674647
+*    128      5000   50000     30906194
+*    129      5000   75000     40905209
+*    130      5000   12500     38939608
+*    131      5000   37500     16752978
+*    132      5000   50000     13302951
+*    133      5000   75000      9830268
+*    134      1000   25000      3804874
+*    135      2500   25000     11729616
+*    136      7500   25000     33318101
+*    137     10000   25000     46426030
+*    138      5000   25000     60710879
+*    139      5000   25000     32729682
+*    140      5000   25000     27183831
+*    141      5000   25000     19963286
+*    142      5000   25000     20243457
+*    143      5000   25000     18586777
+*    144      5000   25000      2504591
+*    145      5000   25000    215956138
+*    146      5000   25000   2253113811
+*    147      5000   25000   -427908373
+*    148      5000   25000    -92965318
+*    149      5000   25000     86051224
+*    150      5000   25000    619314919 */
+
+static const int data[50][1+15] =
+{  {  0, 13502460, 101, 5000, 2500, 2500, 25000,
+      1, 100, 250000, 0, 0, 0, 100, 1, 1000
+   },
+   {  0, 4281922, 102, 5000, 2500, 2500, 25000,
+      1, 100, 2500000, 0, 0, 0, 100, 1, 1000
+   },
+   {  0, 44820113, 103, 5000, 2500, 2500, 25000,
+      1, 100, 6250000, 0, 0, 0, 100, 1, 1000
+   },
+   {  0, 13450451, 104, 5000, 2500, 2500, 25000,
+      -100, -1, 250000, 0, 0, 0, 100, 1, 1000
+   },
+   {  0, 14719436, 105, 5000, 2500, 2500, 25000,
+      101, 200, 250000, 0, 0, 0, 100, 1, 1000
+   },
+   {  0, 17365786, 106, 5000, 2500, 2500, 12500,
+      1, 100, 125000, 0, 0, 0, 100, 1, 1000
+   },
+   {  0, 19540113, 107, 5000, 2500, 2500, 37500,
+      1, 100, 375000, 0, 0, 0, 100, 1, 1000
+   },
+   {  0, 19560313, 108, 5000, 2500, 2500, 50000,
+      1, 100, 500000, 0, 0, 0, 100, 1, 1000
+   },
+   {  0, 2403509, 109, 5000, 2500, 2500, 75000,
+      1, 100, 750000, 0, 0, 0, 100, 1, 1000
+   },
+   {  0, 92480414, 110, 5000, 2500, 2500, 12500,
+      1, 100, 250000, 0, 0, 0, 100, 1, 1000
+   },
+   {  0, 4230140, 111, 5000, 2500, 2500, 37500,
+      1, 100, 250000, 0, 0, 0, 100, 1, 1000
+   },
+   {  0, 10032490, 112, 5000, 2500, 2500, 50000,
+      1, 100, 250000, 0, 0, 0, 100, 1, 1000
+   },
+   {  0, 17307474, 113, 5000, 2500, 2500, 75000,
+      1, 100, 250000, 0, 0, 0, 100, 1, 1000
+   },
+   {  0, 4925114, 114, 5000, 500, 4500, 25000,
+      1, 100, 250000, 0, 0, 0, 100, 1, 1000
+   },
+   {  0, 19842704, 115, 5000, 1500, 3500, 25000,
+      1, 100, 250000, 0, 0, 0, 100, 1, 1000
+   },
+   {  0, 88392060, 116, 5000, 2500, 2500, 25000,
+      1, 100, 250000, 0, 0, 0, 0, 1, 1000
+   },
+   {  0, 12904407, 117, 5000, 2500, 2500, 12500,
+      1, 100, 125000, 0, 0, 0, 0, 1, 1000
+   },
+   {  0, 11811811, 118, 5000, 2500, 2500, 37500,
+      1, 100, 375000, 0, 0, 0, 0, 1, 1000
+   },
+   {  0, 90023593, 119, 5000, 2500, 2500, 50000,
+      1, 100, 500000, 0, 0, 0, 0, 1, 1000
+   },
+   {  0, 93028922, 120, 5000, 2500, 2500, 75000,
+      1, 100, 750000, 0, 0, 0, 0, 1, 1000
+   },
+   {  0, 72707401, 121, 5000, 50, 50, 25000,
+      1, 100, 250000, 50, 50, 0, 100, 1, 1000
+   },
+   {  0, 93040771, 122, 5000, 250, 250, 25000,
+      1, 100, 250000, 250, 250, 0, 100, 1, 1000
+   },
+   {  0, 70220611, 123, 5000, 500, 500, 25000,
+      1, 100, 250000, 500, 500, 0, 100, 1, 1000
+   },
+   {  0, 52774811, 124, 5000, 1000, 1000, 25000,
+      1, 100, 250000, 1000, 1000, 0, 100, 1, 1000
+   },
+   {  0, 22492311, 125, 5000, 1500, 1500, 25000,
+      1, 100, 250000, 1500, 1500, 0, 100, 1, 1000
+   },
+   {  0, 35269337, 126, 5000, 500, 500, 12500,
+      1, 100, 125000, 500, 500, 0, 100, 1, 1000
+   },
+   {  0, 30140502, 127, 5000, 500, 500, 37500,
+      1, 100, 375000, 500, 500, 0, 100, 1, 1000
+   },
+   {  0, 49205455, 128, 5000, 500, 500, 50000,
+      1, 100, 500000, 500, 500, 0, 100, 1, 1000
+   },
+   {  0, 42958341, 129, 5000, 500, 500, 75000,
+      1, 100, 750000, 500, 500, 0, 100, 1, 1000
+   },
+   {  0, 25440925, 130, 5000, 500, 500, 12500,
+      1, 100, 250000, 500, 500, 0, 100, 1, 1000
+   },
+   {  0, 75294924, 131, 5000, 500, 500, 37500,
+      1, 100, 250000, 500, 500, 0, 100, 1, 1000
+   },
+   {  0, 4463965, 132, 5000, 500, 500, 50000,
+      1, 100, 250000, 500, 500, 0, 100, 1, 1000
+   },
+   {  0, 13390427, 133, 5000, 500, 500, 75000,
+      1, 100, 250000, 500, 500, 0, 100, 1, 1000
+   },
+   {  0, 95250971, 134, 1000, 500, 500, 25000,
+      1, 100, 250000, 500, 500, 0, 100, 1, 1000
+   },
+   {  0, 54830522, 135, 2500, 500, 500, 25000,
+      1, 100, 250000, 500, 500, 0, 100, 1, 1000
+   },
+   {  0, 520593, 136, 7500, 500, 500, 25000,
+      1, 100, 250000, 500, 500, 0, 100, 1, 1000
+   },
+   {  0, 52900925, 137, 10000, 500, 500, 25000,
+      1, 100, 250000, 500, 500, 0, 100, 1, 1000
+   },
+   {  0, 22603395, 138, 5000, 500, 500, 25000,
+      1, 100, 250000, 500, 500, 0, 100, 1, 50
+   },
+   {  0, 55253099, 139, 5000, 500, 500, 25000,
+      1, 100, 250000, 500, 500, 0, 100, 1, 250
+   },
+   {  0, 75357001, 140, 5000, 500, 500, 25000,
+      1, 100, 250000, 500, 500, 0, 100, 1, 500
+   },
+   {  0, 10072459, 141, 5000, 500, 500, 25000,
+      1, 100, 250000, 500, 500, 0, 100, 1, 2500
+   },
+   {  0, 55728492, 142, 5000, 500, 500, 25000,
+      1, 100, 250000, 500, 500, 0, 100, 1, 5000
+   },
+   {  0, 593043, 143, 5000, 500, 500, 25000,
+      1, 100, 250000, 500, 500, 0, 0, 1, 1000
+   },
+   {  0, 94236572, 144, 5000, 500, 500, 25000,
+      1, 10, 250000, 500, 500, 0, 100, 1, 1000
+   },
+   {  0, 94882955, 145, 5000, 500, 500, 25000,
+      1, 1000, 250000, 500, 500, 0, 100, 1, 1000
+   },
+   {  0, 48489922, 146, 5000, 500, 500, 25000,
+      1, 10000, 250000, 500, 500, 0, 100, 1, 1000
+   },
+   {  0, 75578374, 147, 5000, 500, 500, 25000,
+      -100, -1, 250000, 500, 500, 0, 100, 1, 1000
+   },
+   {  0, 44821152, 148, 5000, 500, 500, 25000,
+      -50, 49, 250000, 500, 500, 0, 100, 1, 1000
+   },
+   {  0, 45224103, 149, 5000, 500, 500, 25000,
+      101, 200, 250000, 500, 500, 0, 100, 1, 1000
+   },
+   {  0, 63491741, 150, 5000, 500, 500, 25000,
+      1001, 1100, 250000, 500, 500, 0, 100, 1, 1000
+   },
+};
+
+void glp_netgen_prob(int nprob, int parm[1+15])
+{     int k;
+      if (!(101 <= nprob && nprob <= 150))
+         xerror("glp_netgen_prob: nprob = %d; invalid problem instance "
+            "number\n", nprob);
+      for (k = 1; k <= 15; k++)
+         parm[k] = data[nprob-101][k];
+      return;
+}
+
 /**********************************************************************/
 
 #if 0
