@@ -11,7 +11,7 @@
 *  All changes concern only the program interface, so this modified
 *  version produces exactly the same instances as the original version.
 *
-*  Changes were made by Andrew Makhorin <mao@mai2.rcnet.ru>.
+*  Changes were made by Andrew Makhorin <mao@gnu.org>.
 *
 *  GLPK is free software: you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by
@@ -27,7 +27,8 @@
 *  along with GLPK. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
-#include "glpapi.h"
+#include "env.h"
+#include "glpk.h"
 
 /***********************************************************************
 *  NAME
